package com.ruoyi.jarvis.mapper;

import java.util.List;
import com.ruoyi.jarvis.domain.XbMessage;

/**
 * 线报消息Mapper接口
 *
 * @author ruoyi
 */
public interface XbMessageMapper
{
    /**
     * 查询线报消息
     *
     * @param id 线报消息主键
     * @return 线报消息
     */
    public XbMessage selectXbMessageById(Integer id);

    /**
     * 查询线报消息列表
     *
     * @param xbMessage 线报消息
     * @return 线报消息集合
     */
    public List<XbMessage> selectXbMessageList(XbMessage xbMessage);

    /**
     * 新增线报消息
     *
     * @param xbMessage 线报消息
     * @return 结果
     */
    public int insertXbMessage(XbMessage xbMessage);

    /**
     * 修改线报消息
     *
     * @param xbMessage 线报消息
     * @return 结果
     */
    public int updateXbMessage(XbMessage xbMessage);

    /**
     * 删除线报消息
     *
     * @param id 线报消息主键
     * @return 结果
     */
    public int deleteXbMessageById(Integer id);

    /**
     * 批量删除线报消息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteXbMessageByIds(Integer[] ids);
}
